struct FinalFlexLineLayout {
cross_size: Au,
item_fragments: Vec<(Arc<BoxFragment>, PositioningContext)>,
shared_alignment_baseline: Option<Au>,
all_baselines: Baselines,
}Expand description
Once the final cross size of a line is known, the line can go through their final
layout and this the return value. See InitialFlexLineLayout::finish_with_final_cross_size.
Fields
cross_size: AuThe final cross size of this flex line.
item_fragments: Vec<(Arc<BoxFragment>, PositioningContext)>The BoxFragments and PositioningContexts of all flex items,
one per flex item in “order-modified document order.”
The ‘shared alignment baseline’ of this flex line. This is the baseline used for
baseline-aligned items if there are any, otherwise None.
all_baselines: BaselinesThis is the baseline of the first and last items with compatible writing mode, regardless of whether they particpate in baseline alignement. This is used as a fallback baseline for the container, if there are no items participating in baseline alignment in the first or last flex lines.