struct FlexItemLayoutResult {
hypothetical_cross_size: Au,
fragments: Vec<Fragment>,
positioning_context: PositioningContext,
content_baselines_for_parent_relative_to_margin_box: Baselines,
flex_alignment_baseline_relative_to_margin_box: Option<Au>,
content_block_size: Au,
containing_block_size: ContainingBlockSize,
depends_on_block_constraints: bool,
specific_layout_info: Option<SpecificLayoutInfo>,
}Expand description
Return type of FlexItem::layout
Fields
hypothetical_cross_size: Aufragments: Vec<Fragment>positioning_context: PositioningContextcontent_baselines_for_parent_relative_to_margin_box: BaselinesBaselines from the item’s content, relative to the item’s margin box. Used only for baseline propagation to parent layout contexts.
flex_alignment_baseline_relative_to_margin_box: Option<Au>This is the single baseline this item uses for flex alignment. Either the first or the last baseline or None, depending on ‘align-self’.
content_block_size: Aucontaining_block_size: ContainingBlockSizedepends_on_block_constraints: boolspecific_layout_info: Option<SpecificLayoutInfo>Auto Trait Implementations
impl Freeze for FlexItemLayoutResult
impl !RefUnwindSafe for FlexItemLayoutResult
impl Send for FlexItemLayoutResult
impl Sync for FlexItemLayoutResult
impl Unpin for FlexItemLayoutResult
impl UnsafeUnpin for FlexItemLayoutResult
impl !UnwindSafe for FlexItemLayoutResult