struct FlexLineItem<'a> {
item: FlexItem<'a>,
layout_result: FlexItemLayoutResult,
used_main_size: Au,
}Expand description
A data structure to hold all of the information about a flex item that has been placed into a flex line. This happens once the item is laid out and its line has been determined.
Fields
item: FlexItem<'a>The items that are placed in this line.
layout_result: FlexItemLayoutResultThe layout results of the initial layout pass for a flex line. These may be replaced
if necessary due to the use of align-content: stretch or align-self: stretch.
used_main_size: AuThe used main size of this item in its line.
Implementations
Sourceimpl FlexLineItem<'_>
impl FlexLineItem<'_>
fn get_or_synthesize_baseline_with_cross_size( &self, cross_size: Au, flex_container_config: &FlexContainerConfig, ) -> Au
fn collect_fragment( self, initial_flex_layout: &InitialFlexLineLayout<'_>, item_used_size: FlexRelativeVec2<Au>, item_margin: FlexRelativeSides<Au>, item_main_interval: Au, final_line_cross_size: Au, shared_alignment_baseline: &Option<Au>, flex_context: &mut FlexContext<'_>, all_baselines: &mut Baselines, main_position_cursor: &mut Au, ) -> (Arc<BoxFragment>, PositioningContext)