struct InitialFlexLineLayout<'a> {
items: Vec<FlexLineItem<'a>>,
line_size: FlexRelativeVec2<Au>,
free_space_in_main_axis: Au,
}Expand description
The result of splitting the flex items into lines using their intrinsic sizes and doing an initial layout of each item. A final layout still needs to happen after this is produced to handle stretching.
Fields
items: Vec<FlexLineItem<'a>>The items that are placed in this line.
line_size: FlexRelativeVec2<Au>The initial size of this flex line, not taking into account align-content: stretch.
free_space_in_main_axis: AuThe free space available to this line after the initial layout.
Implementations
Sourceimpl InitialFlexLineLayout<'_>
impl InitialFlexLineLayout<'_>
fn new<'items>( flex_context: &FlexContext<'_>, items: Vec<FlexItem<'items>>, outer_hypothetical_main_sizes_sum: Au, container_main_size: Au, main_gap: Au, ) -> InitialFlexLineLayout<'items>
Sourcefn resolve_flexible_lengths<'items>(
items: &'items [FlexItem<'items>],
outer_hypothetical_main_sizes_sum: Au,
container_main_size: Au,
) -> (Vec<Au>, Au)
fn resolve_flexible_lengths<'items>( items: &'items [FlexItem<'items>], outer_hypothetical_main_sizes_sum: Au, container_main_size: Au, ) -> (Vec<Au>, Au)
Return the main size of each item, and the line’s remainaing free space https://drafts.csswg.org/css-flexbox/#resolve-flexible-lengths
Sourcefn cross_size<'items>(
items: &'items [FlexLineItem<'items>],
flex_context: &FlexContext<'_>,
) -> Au
fn cross_size<'items>( items: &'items [FlexLineItem<'items>], flex_context: &FlexContext<'_>, ) -> Au
fn finish_with_final_cross_size( self, flex_context: &mut FlexContext<'_>, main_gap: Au, final_line_cross_size: Au, ) -> FinalFlexLineLayout